@@ -495,7 +495,7 @@ mtarnumreg = function(ini_obj, level = 0.95, burn_m = NULL, niter_m = 1000,
     micluster = parallel::makeCluster(2)
     doParallel::registerDoParallel(micluster)
     funcParallel = function(i,iterprev){return(fill(m = i,iter = iterprev, burn = round(0.3*iterprev)))}
-    parallel::clusterEvalQ(micluster, library(mtar))
+    parallel::clusterEvalQ(micluster, library(BMTAR))
     obj_S = list('ini_obj','burn_m','niter_m','chain_m','list_m',
               'ordersprev','k','N','nu','method','fill','maxpj','maxqj','maxdj',
               'Zt','Yt','Xt','Ut','lists','fycond','rdunif','dmunif','l0_min')
